Welcome to skidward's documentation!
====================================

#### What is this?
Skidward allows you to periodically execute standalone scripts (*here called workers*) on the same namespace,  
managed through a web interface.

As a package, Skidward offers 3 things;  
1. a scheduler for your workers (think cron) focused around high availability,
2. an SDK with basic functionalities to easily GET, POST data and send logs,
3. and a userfriendly web interface to manage everything.

#### Table Of Contents

* [Requirements](src/installation__requirements.md)
* [How to install](src/installation.md)
    
* [How to use](src/usage.md)

* [Available configurations](src/configuration.md)
* [Contribute to the project](src/contribute.md)

* [License](src/license.md)